@@ -1,5 +1,6 @@
 import logging
 import os
+import warnings
 
 from notetool.secret import read_secret
 from sqlalchemy import MetaData, Table, create_engine
@@ -31,8 +32,9 @@ class BaseTable:
                 values = [dict([(k, v) for k, v in item.items() if k in cols]) for item in values]
             elif isinstance(values[0], list):
                 values = [dict(zip(keys, item)) for item in values]
-        insert_stmt = insert(self.table).values(values)
-        self.on_duplicate_key_update(insert_stmt)
 
-    def on_duplicate_key_update(self, insert_stmt):
-        return engine.execute(insert_stmt.on_duplicate_key_update(symbol=insert_stmt.inserted.symbol))
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore")
+            # code here...
+            ins = self.table.insert(values=values).prefix_with("IGNORE")
+            engine.execute(ins)
