@@ -1,6 +1,7 @@
-from sqlalchemy import BIGINT, Column, Float, String, Table
+from sqlalchemy import (BIGINT, Column, Float, String, Table, and_, asc, desc,
+                        func, or_, select)
 
-from .base import BaseTable, meta
+from .base import BaseTable, engine, meta
 
 
 class KlineData(BaseTable):
@@ -14,3 +15,14 @@ class KlineData(BaseTable):
                            Column('low', Float, comment='low', default=0),
                            Column('high', Float, comment='high', default=0),
                            Column('vol', Float, comment='vol', default=0))
+
+    def select_symbol_maxmin(self, symbol):
+        s = select(self.table.columns.symbol,
+                   func.max(self.table.columns.timestamp).label('max_time'),
+                   func.min(self.table.columns.timestamp).label('min_time')
+                   ).where(self.table.columns.symbol == symbol).group_by(self.table.columns.symbol)
+        data = [line for line in engine.execute(s)]
+        if len(data) == 1:
+            return data[0][1], data[0][2]
+        else:
+            return 0, 0
