@@ -20,8 +20,13 @@ class LoadDataKline:
                 self.load(sym, *args, **kwargs)
 
     def load(self, symbol, timeframe='1m', max_retries=3, *args, **kwargs):
-        limit = 1440
+        max_time, min_time = self.table.select_symbol_maxmin(symbol)
+
+        limit = 720
         earliest_timestamp = self.exchange.milliseconds()
+
+        print(min_time, earliest_timestamp)
+
         timeframe_duration_in_seconds = self.exchange.parse_timeframe(timeframe)
         timeframe_duration_in_ms = timeframe_duration_in_seconds * 1000
         timedelta = limit * timeframe_duration_in_ms
@@ -42,11 +47,11 @@ class LoadDataKline:
                 continue
 
             df = pd.DataFrame(result_list, columns=['timestamp', 'open', 'close', 'low', 'high', 'vol'])
-            df['symbol'] = 'btc'
+            df['symbol'] = symbol
             self.table.insert(json.loads(df.to_json(orient='records')))
             earliest_timestamp = result[0][0] - timeframe_duration_in_ms
 
 
-exchan = LoadDataKline(ccxt.okex())
+# exchan.load('BTC/USDT')
 # exchan.load('BTC/USDT')
 exchan.load_all()
